pub struct CompactRow { /* private fields */ }Expand description
A database result row whose column names are shared by the whole result set.
Providers use this representation for typed decoding so a 100-row result does not allocate 100 copies of every projected column name (or 100 B-trees).
Implementations
Sourceimpl CompactRow
impl CompactRow
pub fn new(columns: Arc<[String]>, values: Vec<Value>) -> Self
pub fn get(&self, name: &str) -> Option<&Value>
pub fn get_mut(&mut self, name: &str) -> Option<&mut Value>
Sourcepub fn insert(&mut self, name: String, value: Value) -> Option<Value>
pub fn insert(&mut self, name: String, value: Value) -> Option<Value>
Adds or replaces a projected value. Column layouts remain shared until an enhancement actually changes the shape of this row.
pub fn remove(&mut self, name: &str) -> Option<Value>
pub fn extend(&mut self, other: CompactRow)
pub fn contains_key(&self, name: &str) -> bool
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter(&self) -> impl Iterator<Item = (&String, &Value)>
pub fn keys(&self) -> impl Iterator<Item = &String>
pub fn values(&self) -> impl Iterator<Item = &Value>
pub fn into_map(self) -> BTreeMap<String, Value>