Crate teaql_core

Crate teaql_core 

Macros

register_entities

Structs

Aggregate
AggregationCacheOptions
BaseEntityData
Decimal
Decimal represents a 128 bit representation of a fixed-precision decimal number. The finite set of values of type Decimal are of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.
DeleteCommand
EntityDescriptor
EntityError
EntityGraph
An annotated entity graph ready for saving.
EntityGraphBuilder
Builder for constructing an annotated entity graph that preserves comment trace chains through the save pipeline.
EntityGraphNode
A single node in an annotated entity graph.
InsertCommand
NamedExpr
ObjectGroupBy
OrderBy
PropertyDescriptor
RawSqlProjection
RecoverCommand
RelationAggregate
RelationDescriptor
RelationLoad
SafeExpression
SelectQuery
Slice
SmartList
TraceNode
UpdateCommand
WebAction
WebResponse
WebStyle
XlsBlock
XlsBlockBuildContext
XlsPage
XlsWorkbook

Enums

AggregateFunction
BinaryOp
DataType
EntityGraphOperation
Operation hint for an entity graph node.
Expr
ExprFunction
MutationKind
SortDirection
Value

Constants

ACTION_LIST_KEY
STYLE_KEY
WEB_RESPONSE_VERSION

Traits

BaseEntity
Entity
EntityDescriptorStore
IdentifiableEntity
TeaqlEmpty
TeaqlEntity
VersionedEntity

Functions

default_table_name
record_to_json_value

Type Aliases

Record